package eu.mhsl.minecraft.pixelpic;

import org.bukkit.Bukkit;
import org.bukkit.entity.Player;
import org.bukkit.map.MapCanvas;
import org.bukkit.map.MapRenderer;
import org.bukkit.map.MapView;
import org.jetbrains.annotations.NotNull;

import java.awt.image.BufferedImage;

public class ImageMapRenderer extends MapRenderer {
    public final int IMAGE_SIZE = 128;

    private BufferedImage image;
    private final int x;
    private final int y;

    public ImageMapRenderer(BufferedImage image) {
        this(image, 0, 0);
    }

    public ImageMapRenderer(BufferedImage image, int x, int y) {
        this.x = x;
        this.y = y;
        recalculateInput(image);
    }

    public void recalculateInput(BufferedImage input) {
        if (x * IMAGE_SIZE > input.getWidth() || y * IMAGE_SIZE > input.getHeight())
            throw new RuntimeException(String.format("Input image mus match a multiple of x and y with %d", IMAGE_SIZE));

        int x1 = (int) (double) (x * IMAGE_SIZE);
        int y1 = (int) (double) (y * IMAGE_SIZE);

        int x2 = (int) (double) Math.min(input.getWidth(), ((x + 1) * IMAGE_SIZE));
        int y2 = (int) (double) Math.min(input.getHeight(), ((y + 1) * IMAGE_SIZE));

        if (x2 - x1 <= 0 || y2 - y1 <= 0)
            return;

        this.image = input.getSubimage(x1, y1, x2 - x1, y2 - y1);
    }

    @Override
    public void render(@NotNull MapView map, @NotNull MapCanvas canvas, @NotNull Player player) {
        if(image == null) return;
        Bukkit.getScheduler().runTaskLater(Main.getInstance(), () -> canvas.drawImage(0, 0, image), 2L);
    }
}
